# Contributing

## Branches

All active development are on the `main` branch and releases are made on git
tags.

## Contributing Code

This project uses [hatch](https://hatch.pypa.io/latest/) as its Python project
manager.

Pre-commit is available to help you pass the pull request checks.

## Making a New Release

1. Create and increment Github releases.
2. Build and release to PyPI with hatch (CI TBD).
